@@ -1,7 +1,9 @@
+from typing import Dict
+
 from . import dataset
 from . import helpers
 import os
-import pandas as pd
+
 
 class Albadi2018(dataset.Dataset):
     
@@ -25,10 +27,10 @@ class Albadi2018(dataset.Dataset):
     license = """UNKNOWN"""
 
     @classmethod
-    def process(cls, tmp_file_path, dataset_folder):
+    def process(cls, tmp_file_path, dataset_folder, api_config):
         file_dir = helpers.unzip_file(tmp_file_path)
-        train_file = helpers.download_tweets_for_csv(os.path.join(file_dir, "Arabic_hatespeech-master/train.csv"), "id")
-        test_file = helpers.download_tweets_for_csv(os.path.join(file_dir, "Arabic_hatespeech-master/test.csv"), "id")
+        train_file = helpers.download_tweets_for_csv(os.path.join(file_dir, "Arabic_hatespeech-master/train.csv"), "id", api_config)
+        test_file = helpers.download_tweets_for_csv(os.path.join(file_dir, "Arabic_hatespeech-master/test.csv"), "id", api_config)
         helpers.copy_file(train_file, os.path.join(dataset_folder, "albadi2018ar_train.csv"))
         helpers.copy_file(test_file, os.path.join(dataset_folder, "albadi2018ar_test.csv"))
 
