@@ -1,7 +1,7 @@
 from . import dataset
 import os
 from . import helpers
-import pandas as pd
+
 
 class Coltekin2019(dataset.Dataset):
     
@@ -20,7 +20,7 @@ class Coltekin2019(dataset.Dataset):
     license = """UNKNOWN"""
 
     @classmethod
-    def process(cls, tmp_file_path, dataset_folder):
+    def process(cls, tmp_file_path, dataset_folder, api_config):
         zip_file_path = helpers.unzip_file(tmp_file_path)
         file1 = os.path.join(zip_file_path, "offenseval2020-turkish/offenseval-tr-testset-v1/offenseval-tr-labela-v1.tsv")
         file1 = helpers.clean_csv(file1, sep=",", names=["lid", "class"])
