@@ -1,7 +1,7 @@
 from . import dataset
 import os
 from . import helpers
-import pandas as pd
+
 
 class Fortuna2019(dataset.Dataset):
     
@@ -20,8 +20,8 @@ class Fortuna2019(dataset.Dataset):
     license = """UNKNOWN"""
 
     @classmethod
-    def process(cls, tmp_file_path, dataset_folder):
-        tmp_file_path = helpers.download_tweets_for_csv(tmp_file_path, "tweet_id")
+    def process(cls, tmp_file_path, dataset_folder, api_config):
+        tmp_file_path = helpers.download_tweets_for_csv(tmp_file_path, "tweet_id", api_config)
         helpers.copy_file(tmp_file_path, os.path.join(dataset_folder, "fortuna2019pt.csv"))
 
     @classmethod
