@@ -1,7 +1,7 @@
 from . import dataset
 import os
 from . import helpers
-import pandas as pd
+
 
 class Founta2018(dataset.Dataset):
     
@@ -20,9 +20,9 @@ class Founta2018(dataset.Dataset):
     license = """UNKNOWN"""
 
     @classmethod
-    def process(cls, tmp_file_path, dataset_folder):
+    def process(cls, tmp_file_path, dataset_folder, api_config):
         tmp_file_path = helpers.clean_csv(tmp_file_path, names=["tweet", "class"])
-        tmp_file_path = helpers.download_tweets_for_csv(tmp_file_path, "tweet")
+        tmp_file_path = helpers.download_tweets_for_csv(tmp_file_path, "tweet", api_config)
         helpers.copy_file(tmp_file_path, os.path.join(dataset_folder, "founta2018en.csv"))
 
     @classmethod
