@@ -1,7 +1,7 @@
 from . import dataset
 from . import helpers
 import os
-import pandas as pd
+
 
 class Mathur2018(dataset.Dataset):
     
@@ -19,7 +19,7 @@ class Mathur2018(dataset.Dataset):
     license = """UNKNOWN"""
 
     @classmethod
-    def process(cls, tmp_file_path, dataset_folder):
+    def process(cls, tmp_file_path, dataset_folder, api_config):
         tmp_file_path = helpers.clean_csv(tmp_file_path, names=["text", "translation", "class"])
         helpers.copy_file(tmp_file_path, os.path.join(dataset_folder, "mathur2018hing.csv"))
 
