@@ -1,7 +1,7 @@
 from . import dataset
 from . import helpers
 import os
-import pandas as pd
+
 
 class Novak2021(dataset.Dataset):
     
@@ -19,8 +19,8 @@ class Novak2021(dataset.Dataset):
     license = """UNKNOWN"""
 
     @classmethod
-    def process(cls, tmp_file_path, dataset_folder):
-        tmp_file_path = helpers.download_tweets_for_csv(tmp_file_path, "ID")
+    def process(cls, tmp_file_path, dataset_folder, api_config):
+        tmp_file_path = helpers.download_tweets_for_csv(tmp_file_path, "ID", api_config)
         helpers.copy_file(tmp_file_path, os.path.join(dataset_folder, "novak2021sl.csv"))
 
     @classmethod
