@@ -1,7 +1,7 @@
 from . import dataset
 from . import helpers
 import os
-import pandas as pd
+
 
 class Ross2017(dataset.Dataset):
     
@@ -19,7 +19,7 @@ class Ross2017(dataset.Dataset):
     license = """UNKNOWN"""
     
     @classmethod
-    def process(cls, tmp_file_path, dataset_folder):
+    def process(cls, tmp_file_path, dataset_folder, api_config):
         helpers.copy_file(tmp_file_path, os.path.join(dataset_folder, "ross2018de.csv"))
 
     @classmethod
