@@ -1,7 +1,7 @@
 from . import dataset
 from . import helpers
 import os
-import pandas as pd
+
 
 class Sigurbergsson2019(dataset.Dataset):
     
@@ -19,7 +19,7 @@ class Sigurbergsson2019(dataset.Dataset):
     license = """UNKNOWN"""
 
     @classmethod
-    def process(cls, tmp_file_path, dataset_folder):
+    def process(cls, tmp_file_path, dataset_folder, api_config):
         # read write to convert csv seperator to ","
         helpers.untarbz_file(tmp_file_path)
         tmp_file_path = os.path.join(os.path.dirname(tmp_file_path), "dkhate/oe20da_data/offenseval-da-training-v1.tsv")
