@@ -1,8 +1,7 @@
 from . import dataset
 from . import helpers
 import os
-import pandas as pd
-import json
+
 
 class Waseem2016(dataset.Dataset):
     
@@ -20,9 +19,9 @@ class Waseem2016(dataset.Dataset):
     license = """ """
 
     @classmethod
-    def process(cls, tmp_file_path, dataset_folder):
+    def process(cls, tmp_file_path, dataset_folder, api_config):
         tmp_file_path = helpers.clean_csv(tmp_file_path, ["twitter_ids", "tag"])
-        tmp_file_path = helpers.download_tweets_for_csv(tmp_file_path, "twitter_ids")
+        tmp_file_path = helpers.download_tweets_for_csv(tmp_file_path, "twitter_ids", api_config)
         helpers.copy_file(tmp_file_path, os.path.join(dataset_folder, "waseem2016en.csv"))
 
     @classmethod
@@ -30,5 +29,3 @@ class Waseem2016(dataset.Dataset):
         row["labels"] = [row["tag"]]
         row = row.drop(["tag"])
         return row
-        
-        
