@@ -1,7 +1,7 @@
 from . import dataset
 from . import helpers
 import os
-import pandas as pd
+
 
 class Wiegand2018(dataset.Dataset):
     
@@ -21,8 +21,8 @@ class Wiegand2018(dataset.Dataset):
 Michael Wiegand, Melanie Siegel, and Josef Ruppenhofer: "Overview of the GermEval 2018 Shared Task on the Identification of Offensive Language", in Proceedings of the GermEval, 2018, Vienna, Austria."""
 
     @classmethod
-    def process(cls, tmp_file_path, dataset_folder):
-        tmp_file_path = helpers.clean_csv(tmp_file_path, names=["text","tag1", "tag2"], sep='\t')
+    def process(cls, tmp_file_path, dataset_folder, api_config):
+        tmp_file_path = helpers.clean_csv(tmp_file_path, names=["text", "tag1", "tag2"], sep='\t')
         helpers.copy_file(tmp_file_path, os.path.join(dataset_folder, "wiegand2018de.csv"))
 
     @classmethod
