@@ -1,7 +1,7 @@
 from . import dataset
 from . import helpers
 import os
-import pandas as pd
+
 
 class Zampieri2019(dataset.Dataset):
     
@@ -19,7 +19,7 @@ class Zampieri2019(dataset.Dataset):
     license = """UNKNOWN"""
 
     @classmethod
-    def process(cls, tmp_file_path, dataset_folder):
+    def process(cls, tmp_file_path, dataset_folder, api_config):
         tmp_file_path = helpers.clean_csv(tmp_file_path, sep="\t")
         helpers.copy_file(tmp_file_path, os.path.join(dataset_folder, "zampieri2019en.csv"))
 
